==> rice-impex-server-demo-2.1.14-sql.jar: sql/mysql/KREW_DOC_TYP_PROC_T.sql <==
TRUNCATE TABLE KREW_DOC_TYP_PROC_T
/
INSERT INTO KREW_DOC_TYP_PROC_T (DOC_TYP_ID,DOC_TYP_PROC_ID,INIT_IND,INIT_RTE_NODE_ID,NM,VER_NBR)
  VALUES ('2011','2005',1,'2004','PRIMARY',2)
/
INSERT INTO KREW_DOC_TYP_PROC_T (DOC_TYP_ID,DOC_TYP_PROC_ID,INIT_IND,INIT_RTE_NODE_ID,NM,VER_NBR)
  VALUES ('2012','2007',1,'2006','PRIMARY',2)
/
INSERT INTO KREW_DOC_TYP_PROC_T (DOC_TYP_ID,DOC_TYP_PROC_ID,INIT_IND,INIT_RTE_NODE_ID,NM,VER_NBR)
  VALUES ('2023','2040',1,'2039','PRIMARY',1)
/
INSERT INTO KREW_DOC_TYP_PROC_T (DOC_TYP_ID,DOC_TYP_PROC_ID,INIT_IND,INIT_RTE_NODE_ID,NM,VER_NBR)
  VALUES ('2024','2044',1,'2041','PRIMARY',1)
/
INSERT INTO KREW_DOC_TYP_PROC_T (DOC_TYP_ID,DOC_TYP_PROC_ID,INIT_IND,INIT_RTE_NODE_ID,NM,VER_NBR)
  VALUES ('2030','2060',1,'2059','PRIMARY',1)
/
INSERT INTO KREW_DOC_TYP_PROC_T (DOC_TYP_ID,DOC_TYP_PROC_ID,INIT_IND,INIT_RTE_NODE_ID,NM,VER_NBR)
  VALUES ('2031','2062',1,'2061','PRIMARY',1)
/
INSERT INTO KREW_DOC_TYP_PROC_T (DOC_TYP_ID,DOC_TYP_PROC_ID,INIT_IND,INIT_RTE_NODE_ID,NM,VER_NBR)
  VALUES ('2032','2064',1,'2063','PRIMARY',1)
/
INSERT INTO KREW_DOC_TYP_PROC_T (DOC_TYP_ID,DOC_TYP_PROC_ID,INIT_IND,INIT_RTE_NODE_ID,NM,VER_NBR)
  VALUES ('2033','2066',1,'2065','PRIMARY',1)
/
INSERT INTO KREW_DOC_TYP_PROC_T (DOC_TYP_ID,DOC_TYP_PROC_ID,INIT_IND,INIT_RTE_NODE_ID,NM,VER_NBR)
  VALUES ('2034','2068',1,'2067','PRIMARY',1)
/
INSERT INTO KREW_DOC_TYP_PROC_T (DOC_TYP_ID,DOC_TYP_PROC_ID,INIT_IND,INIT_RTE_NODE_ID,NM,VER_NBR)
  VALUES ('2282','2345',1,'2344','PRIMARY',1)
/
INSERT INTO KREW_DOC_TYP_PROC_T (DOC_TYP_ID,DOC_TYP_PROC_ID,INIT_IND,INIT_RTE_NODE_ID,NM,VER_NBR)
  VALUES ('2440','2582',1,'2580','PRIMARY',1)
/
INSERT INTO KREW_DOC_TYP_PROC_T (DOC_TYP_ID,DOC_TYP_PROC_ID,INIT_IND,INIT_RTE_NODE_ID,NM,VER_NBR)
  VALUES ('2680','2841',1,'2840','PRIMARY',2)
/
INSERT INTO KREW_DOC_TYP_PROC_T (DOC_TYP_ID,DOC_TYP_PROC_ID,INIT_IND,INIT_RTE_NODE_ID,NM,VER_NBR)
  VALUES ('2683','2851',1,'2846','PRIMARY',1)
/
INSERT INTO KREW_DOC_TYP_PROC_T (DOC_TYP_ID,DOC_TYP_PROC_ID,INIT_IND,INIT_RTE_NODE_ID,NM,VER_NBR)
  VALUES ('2704','2894',1,'2892','PRIMARY',4)
/
INSERT INTO KREW_DOC_TYP_PROC_T (DOC_TYP_ID,DOC_TYP_PROC_ID,INIT_IND,INIT_RTE_NODE_ID,NM,VER_NBR)
  VALUES ('2707','2897',1,'2895','PRIMARY',1)
/
INSERT INTO KREW_DOC_TYP_PROC_T (DOC_TYP_ID,DOC_TYP_PROC_ID,INIT_IND,INIT_RTE_NODE_ID,NM,VER_NBR)
  VALUES ('2995','2900',1,'2898','PRIMARY',1)
/
INSERT INTO KREW_DOC_TYP_PROC_T (DOC_TYP_ID,DOC_TYP_PROC_ID,INIT_IND,INIT_RTE_NODE_ID,NM,VER_NBR)
  VALUES ('2996','2903',1,'2901','PRIMARY',1)
/
INSERT INTO KREW_DOC_TYP_PROC_T (DOC_TYP_ID,DOC_TYP_PROC_ID,INIT_IND,INIT_RTE_NODE_ID,NM,VER_NBR)
  VALUES ('2997','2907',1,'2904','PRIMARY',1)
/
INSERT INTO KREW_DOC_TYP_PROC_T (DOC_TYP_ID,DOC_TYP_PROC_ID,INIT_IND,INIT_RTE_NODE_ID,NM,VER_NBR)
  VALUES ('2998','2909',1,'2908','PRIMARY',1)
/
INSERT INTO KREW_DOC_TYP_PROC_T (DOC_TYP_ID,DOC_TYP_PROC_ID,INIT_IND,INIT_RTE_NODE_ID,NM,VER_NBR)
  VALUES ('2999','2911',1,'2910','PRIMARY',1)
/
INSERT INTO KREW_DOC_TYP_PROC_T (DOC_TYP_ID,DOC_TYP_PROC_ID,INIT_IND,INIT_RTE_NODE_ID,NM,VER_NBR)
  VALUES ('3006','2916',1,'2914','PRIMARY',1)
/
INSERT INTO KREW_DOC_TYP_PROC_T (DOC_TYP_ID,DOC_TYP_PROC_ID,INIT_IND,INIT_RTE_NODE_ID,NM,VER_NBR)
  VALUES ('3007','2918',1,'2917','PRIMARY',1)
/

==> rice-impex-server-demo-2.5.14-sql.jar: sql/mysql/KREW_DOC_TYP_PROC_T.sql <==
TRUNCATE TABLE KREW_DOC_TYP_PROC_T
/
INSERT INTO KREW_DOC_TYP_PROC_T (DOC_TYP_ID,DOC_TYP_PROC_ID,INIT_IND,INIT_RTE_NODE_ID,NM,VER_NBR)
  VALUES ('2011','2005',1,'2004','PRIMARY',2)
/
INSERT INTO KREW_DOC_TYP_PROC_T (DOC_TYP_ID,DOC_TYP_PROC_ID,INIT_IND,INIT_RTE_NODE_ID,NM,VER_NBR)
  VALUES ('2012','2007',1,'2006','PRIMARY',2)
/
INSERT INTO KREW_DOC_TYP_PROC_T (DOC_TYP_ID,DOC_TYP_PROC_ID,INIT_IND,INIT_RTE_NODE_ID,NM,VER_NBR)
  VALUES ('2023','2040',1,'2039','PRIMARY',1)
/
INSERT INTO KREW_DOC_TYP_PROC_T (DOC_TYP_ID,DOC_TYP_PROC_ID,INIT_IND,INIT_RTE_NODE_ID,NM,VER_NBR)
  VALUES ('2024','2044',1,'2041','PRIMARY',1)
/
INSERT INTO KREW_DOC_TYP_PROC_T (DOC_TYP_ID,DOC_TYP_PROC_ID,INIT_IND,INIT_RTE_NODE_ID,NM,VER_NBR)
  VALUES ('2029','2058',1,'2057','PRIMARY',2)
/
INSERT INTO KREW_DOC_TYP_PROC_T (DOC_TYP_ID,DOC_TYP_PROC_ID,INIT_IND,INIT_RTE_NODE_ID,NM,VER_NBR)
  VALUES ('2030','2060',1,'2059','PRIMARY',1)
/
INSERT INTO KREW_DOC_TYP_PROC_T (DOC_TYP_ID,DOC_TYP_PROC_ID,INIT_IND,INIT_RTE_NODE_ID,NM,VER_NBR)
  VALUES ('2031','2062',1,'2061','PRIMARY',1)
/
INSERT INTO KREW_DOC_TYP_PROC_T (DOC_TYP_ID,DOC_TYP_PROC_ID,INIT_IND,INIT_RTE_NODE_ID,NM,VER_NBR)
  VALUES ('2032','2064',1,'2063','PRIMARY',1)
/
INSERT INTO KREW_DOC_TYP_PROC_T (DOC_TYP_ID,DOC_TYP_PROC_ID,INIT_IND,INIT_RTE_NODE_ID,NM,VER_NBR)
  VALUES ('2033','2066',1,'2065','PRIMARY',1)
/
INSERT INTO KREW_DOC_TYP_PROC_T (DOC_TYP_ID,DOC_TYP_PROC_ID,INIT_IND,INIT_RTE_NODE_ID,NM,VER_NBR)
  VALUES ('2034','2068',1,'2067','PRIMARY',1)
/
INSERT INTO KREW_DOC_TYP_PROC_T (DOC_TYP_ID,DOC_TYP_PROC_ID,INIT_IND,INIT_RTE_NODE_ID,NM,VER_NBR)
  VALUES ('2282','2345',1,'2344','PRIMARY',1)
/
INSERT INTO KREW_DOC_TYP_PROC_T (DOC_TYP_ID,DOC_TYP_PROC_ID,INIT_IND,INIT_RTE_NODE_ID,NM,VER_NBR)
  VALUES ('2440','2582',1,'2580','PRIMARY',1)
/
INSERT INTO KREW_DOC_TYP_PROC_T (DOC_TYP_ID,DOC_TYP_PROC_ID,INIT_IND,INIT_RTE_NODE_ID,NM,VER_NBR)
  VALUES ('2680','2841',1,'2840','PRIMARY',2)
/
INSERT INTO KREW_DOC_TYP_PROC_T (DOC_TYP_ID,DOC_TYP_PROC_ID,INIT_IND,INIT_RTE_NODE_ID,NM,VER_NBR)
  VALUES ('2683','2851',1,'2846','PRIMARY',1)
/
INSERT INTO KREW_DOC_TYP_PROC_T (DOC_TYP_ID,DOC_TYP_PROC_ID,INIT_IND,INIT_RTE_NODE_ID,NM,VER_NBR)
  VALUES ('2704','2894',1,'2892','PRIMARY',4)
/
INSERT INTO KREW_DOC_TYP_PROC_T (DOC_TYP_ID,DOC_TYP_PROC_ID,INIT_IND,INIT_RTE_NODE_ID,NM,VER_NBR)
  VALUES ('2707','2897',1,'2895','PRIMARY',1)
/
INSERT INTO KREW_DOC_TYP_PROC_T (DOC_TYP_ID,DOC_TYP_PROC_ID,INIT_IND,INIT_RTE_NODE_ID,NM,VER_NBR)
  VALUES ('2995','2900',1,'2898','PRIMARY',1)
/
INSERT INTO KREW_DOC_TYP_PROC_T (DOC_TYP_ID,DOC_TYP_PROC_ID,INIT_IND,INIT_RTE_NODE_ID,NM,VER_NBR)
  VALUES ('2996','2903',1,'2901','PRIMARY',1)
/
INSERT INTO KREW_DOC_TYP_PROC_T (DOC_TYP_ID,DOC_TYP_PROC_ID,INIT_IND,INIT_RTE_NODE_ID,NM,VER_NBR)
  VALUES ('2997','2907',1,'2904','PRIMARY',1)
/
INSERT INTO KREW_DOC_TYP_PROC_T (DOC_TYP_ID,DOC_TYP_PROC_ID,INIT_IND,INIT_RTE_NODE_ID,NM,VER_NBR)
  VALUES ('2998','2909',1,'2908','PRIMARY',1)
/
INSERT INTO KREW_DOC_TYP_PROC_T (DOC_TYP_ID,DOC_TYP_PROC_ID,INIT_IND,INIT_RTE_NODE_ID,NM,VER_NBR)
  VALUES ('2999','2911',1,'2910','PRIMARY',1)
/
INSERT INTO KREW_DOC_TYP_PROC_T (DOC_TYP_ID,DOC_TYP_PROC_ID,INIT_IND,INIT_RTE_NODE_ID,NM,VER_NBR)
  VALUES ('3006','2916',1,'2914','PRIMARY',1)
/
INSERT INTO KREW_DOC_TYP_PROC_T (DOC_TYP_ID,DOC_TYP_PROC_ID,INIT_IND,INIT_RTE_NODE_ID,NM,VER_NBR)
  VALUES ('3007','2918',1,'2917','PRIMARY',1)
/
INSERT INTO KREW_DOC_TYP_PROC_T (DOC_TYP_ID,DOC_TYP_PROC_ID,INIT_IND,INIT_RTE_NODE_ID,NM,VER_NBR)
  VALUES ('3008','2920',1,'2919','PRIMARY',1)
/
INSERT INTO KREW_DOC_TYP_PROC_T (DOC_TYP_ID,DOC_TYP_PROC_ID,INIT_IND,INIT_RTE_NODE_ID,NM,VER_NBR)
  VALUES ('3009','2922',1,'2921','PRIMARY',1)
/
INSERT INTO KREW_DOC_TYP_PROC_T (DOC_TYP_ID,DOC_TYP_PROC_ID,INIT_IND,INIT_RTE_NODE_ID,NM,VER_NBR)
  VALUES ('3012','2923',1,'2924','PRIMARY',1)
/
INSERT INTO KREW_DOC_TYP_PROC_T (DOC_TYP_ID,DOC_TYP_PROC_ID,INIT_IND,INIT_RTE_NODE_ID,NM,VER_NBR)
  VALUES ('3015','2925',1,'2926','PRIMARY',1)
/
INSERT INTO KREW_DOC_TYP_PROC_T (DOC_TYP_ID,DOC_TYP_PROC_ID,INIT_IND,INIT_RTE_NODE_ID,NM,VER_NBR)
  VALUES ('3016','2927',1,'2928','PRIMARY',1)
/
INSERT INTO KREW_DOC_TYP_PROC_T (DOC_TYP_ID,DOC_TYP_PROC_ID,INIT_IND,INIT_RTE_NODE_ID,NM,VER_NBR)
  VALUES ('3017','2929',1,'2930','PRIMARY',1)
/
INSERT INTO KREW_DOC_TYP_PROC_T (DOC_TYP_ID,DOC_TYP_PROC_ID,INIT_IND,INIT_RTE_NODE_ID,NM,VER_NBR)
  VALUES ('3018','2931',1,'2932','PRIMARY',1)
/
INSERT INTO KREW_DOC_TYP_PROC_T (DOC_TYP_ID,DOC_TYP_PROC_ID,INIT_IND,INIT_RTE_NODE_ID,NM,VER_NBR)
  VALUES ('3019','2933',1,'2934','PRIMARY',1)
/
INSERT INTO KREW_DOC_TYP_PROC_T (DOC_TYP_ID,DOC_TYP_PROC_ID,INIT_IND,INIT_RTE_NODE_ID,NM,VER_NBR)
  VALUES ('3022','2935',1,'2936','PRIMARY',1)
/
INSERT INTO KREW_DOC_TYP_PROC_T (DOC_TYP_ID,DOC_TYP_PROC_ID,INIT_IND,INIT_RTE_NODE_ID,NM,VER_NBR)
  VALUES ('3023','2937',1,'2938','PRIMARY',1)
/
INSERT INTO KREW_DOC_TYP_PROC_T (DOC_TYP_ID,DOC_TYP_PROC_ID,INIT_IND,INIT_RTE_NODE_ID,NM,VER_NBR)
  VALUES ('3024','2940',1,'2941','PRIMARY',1)
/
INSERT INTO KREW_DOC_TYP_PROC_T (DOC_TYP_ID,DOC_TYP_PROC_ID,INIT_IND,INIT_RTE_NODE_ID,NM,VER_NBR)
  VALUES ('3025','2944',1,'2945','PRIMARY',1)
/
INSERT INTO KREW_DOC_TYP_PROC_T (DOC_TYP_ID,DOC_TYP_PROC_ID,INIT_IND,INIT_RTE_NODE_ID,NM,VER_NBR)
  VALUES ('3026','2946',1,'2947','PRIMARY',1)
/
INSERT INTO KREW_DOC_TYP_PROC_T (DOC_TYP_ID,DOC_TYP_PROC_ID,INIT_IND,INIT_RTE_NODE_ID,NM,VER_NBR)
  VALUES ('3027','2949',1,'2950','PRIMARY',1)
/
INSERT INTO KREW_DOC_TYP_PROC_T (DOC_TYP_ID,DOC_TYP_PROC_ID,INIT_IND,INIT_RTE_NODE_ID,NM,VER_NBR)
  VALUES ('3028','2951',1,'2952','PRIMARY',1)
/
INSERT INTO KREW_DOC_TYP_PROC_T (DOC_TYP_ID,DOC_TYP_PROC_ID,INIT_IND,INIT_RTE_NODE_ID,NM,VER_NBR)
  VALUES ('3029','2954',1,'2955','PRIMARY',1)
/
INSERT INTO KREW_DOC_TYP_PROC_T (DOC_TYP_ID,DOC_TYP_PROC_ID,INIT_IND,INIT_RTE_NODE_ID,NM,VER_NBR)
  VALUES ('3030','2957',1,'2958','PRIMARY',1)
/
INSERT INTO KREW_DOC_TYP_PROC_T (DOC_TYP_ID,DOC_TYP_PROC_ID,INIT_IND,INIT_RTE_NODE_ID,NM,VER_NBR)
  VALUES ('3032','2960',1,'2961','PRIMARY',1)
/
INSERT INTO KREW_DOC_TYP_PROC_T (DOC_TYP_ID,DOC_TYP_PROC_ID,INIT_IND,INIT_RTE_NODE_ID,NM,VER_NBR)
  VALUES ('3033','2962',1,'2963','PRIMARY',1)
/
INSERT INTO KREW_DOC_TYP_PROC_T (DOC_TYP_ID,DOC_TYP_PROC_ID,INIT_IND,INIT_RTE_NODE_ID,NM,VER_NBR)
  VALUES ('3034','2964',1,'2965','PRIMARY',1)
/
INSERT INTO KREW_DOC_TYP_PROC_T (DOC_TYP_ID,DOC_TYP_PROC_ID,INIT_IND,INIT_RTE_NODE_ID,NM,VER_NBR)
  VALUES ('3035','2966',1,'2967','PRIMARY',1)
/
INSERT INTO KREW_DOC_TYP_PROC_T (DOC_TYP_ID,DOC_TYP_PROC_ID,INIT_IND,INIT_RTE_NODE_ID,NM,VER_NBR)
  VALUES ('3036','2968',1,'2969','PRIMARY',1)
/
INSERT INTO KREW_DOC_TYP_PROC_T (DOC_TYP_ID,DOC_TYP_PROC_ID,INIT_IND,INIT_RTE_NODE_ID,NM,VER_NBR)
  VALUES ('3037','2970',1,'2971','PRIMARY',1)
/
INSERT INTO KREW_DOC_TYP_PROC_T (DOC_TYP_ID,DOC_TYP_PROC_ID,INIT_IND,INIT_RTE_NODE_ID,NM,VER_NBR)
  VALUES ('3038','2972',1,'2973','PRIMARY',1)
/
INSERT INTO KREW_DOC_TYP_PROC_T (DOC_TYP_ID,DOC_TYP_PROC_ID,INIT_IND,INIT_RTE_NODE_ID,NM,VER_NBR)
  VALUES ('3039','2974',1,'2975','PRIMARY',1)
/
INSERT INTO KREW_DOC_TYP_PROC_T (DOC_TYP_ID,DOC_TYP_PROC_ID,INIT_IND,INIT_RTE_NODE_ID,NM,VER_NBR)
  VALUES ('3041','2976',1,'2977','PRIMARY',1)
/
INSERT INTO KREW_DOC_TYP_PROC_T (DOC_TYP_ID,DOC_TYP_PROC_ID,INIT_IND,INIT_RTE_NODE_ID,NM,VER_NBR)
  VALUES ('3042','2978',1,'2979','PRIMARY',1)
/
INSERT INTO KREW_DOC_TYP_PROC_T (DOC_TYP_ID,DOC_TYP_PROC_ID,INIT_IND,INIT_RTE_NODE_ID,NM,VER_NBR)
  VALUES ('3043','2981',1,'2982','PRIMARY',1)
/
INSERT INTO KREW_DOC_TYP_PROC_T (DOC_TYP_ID,DOC_TYP_PROC_ID,INIT_IND,INIT_RTE_NODE_ID,NM,VER_NBR)
  VALUES ('3044','2983',1,'2984','PRIMARY',1)
/
